<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Session;
use App\Order;
use App\CustomerPackage;

class MpesaController extends Controller
{
    public function pay()
    {
        if(Session::has('payment_type')){
            if(Session::get('payment_type') == 'cart_payment'){
                $order = Order::findOrFail(Session::get('order_id'));
                return view('frontend.mpesa.order_payment_mpesa', compact('order'));
            }
            elseif (Session::get('payment_type') == 'wallet_payment') {
                return view('frontend.mpesa.wallet_payment_mpesa');
            }
            elseif (Session::get('payment_type') == 'customer_package_payment') {
                $customer_package_id = Session::get('payment_data')['customer_package_id'];
                $customer_package  = CustomerPackage::findOrFail($customer_package_id);
                return view('frontend.mpesa.customer_package_payment_mpesa', compact('customer_package'));
            }
            elseif (Session::get('payment_type') == 'seller_package_payment') {
                $seller_package_id = Session::get('payment_data')['seller_package_id'];
                $seller_package  = \App\SellerPackage::findOrFail($seller_package_id);
                return view('frontend.mpesa.seller_package_payment_mpesa', compact('seller_package'));
            }
        }
    }

    public function payment_complete(Request $request)
    {
        $mpesa = new \Safaricom\Mpesa\Mpesa();
        if(Session::has('order_id')) {
            $order = Order::find(Session::get('order_id'));
            $c2bTransaction = $mpesa->c2b(env('MPESA_SHORT_CODE'), $request->CommandID, $order->grand_total, $request->Msisdn, $request->BillRefNumber);
        } else if(Session::has('payment_type') && Session::get('payment_type') == 'wallet_payment') {
            $c2bTransaction = $mpesa->c2b(env('MPESA_SHORT_CODE'), $request->CommandID, Session::get('payment_data')['amount'], $request->Msisdn, $request->BillRefNumber);
        } else if(Session::has('payment_type') && Session::get('payment_type') == 'customer_package_payment') {
            $payment_data = Session::get('payment_data');
            $customer_package_id = $payment_data['customer_package_id'];
            $customer_package_price = CustomerPackage::findOrFail($customer_package_id)->amount;

            $c2bTransaction = $mpesa->c2b(env('MPESA_SHORT_CODE'), $request->CommandID, $customer_package_price, $request->Msisdn, $request->BillRefNumber);
        } else if(Session::has('payment_type') && Session::get('payment_type') == 'seller_package_payment') {
            $payment_data = Session::get('payment_data');
            $seller_package_id = $payment_data['seller_package_id'];
            $seller_package_price = \App\SellerPackage::findOrFail($seller_package_id)->amount;

            $c2bTransaction = $mpesa->c2b(env('MPESA_SHORT_CODE'), $request->CommandID, $seller_package_price, $request->Msisdn, $request->BillRefNumber);
        }
        $payment_type = Session::get('payment_type');

        $payment = json_decode($c2bTransaction);

        try{
            $response = json_decode($c2bTransaction)->ResponseDescription;

            if(strcmp($response, 'Accept the service request successfully.') != 0){
                // fail or cancel or incomplete
                Session::forget('payment_data');
                flash(translate('Payment incomplete'))->error();
                return redirect()->route('home');

            } else {
                if ($payment_type == 'cart_payment') {
                    $checkoutController = new CheckoutController;
                    return $checkoutController->checkout_done(session()->get('order_id'), json_encode($payment));
                }

                if ($payment_type == 'wallet_payment') {
                    $walletController = new WalletController;
                    return $walletController->wallet_payment_done(session()->get('payment_data'), json_encode($payment));
                }

                if ($payment_type == 'customer_package_payment') {
                    $customer_package_controller = new CustomerPackageController;
                    return $customer_package_controller->purchase_payment_done(session()->get('payment_data'), json_encode($payment));
                }
                if($payment_type == 'seller_package_payment') {
                    $seller_package_controller = new \App\Http\Controllers\SellerPackageController;
                    return $seller_package_controller->purchase_payment_done(session()->get('payment_data'), json_encode($payment));
                }
            }
        }
        catch (\Exception $e) {
            flash(translate('Payment failed'))->error();
    	    return redirect()->route('home');
        }

    }
}
